import {EventEmitter2} from 'eventemitter2';
import {Call} from './Call';
import {CallLog} from './CallLog';
import {RemoteCall} from './RemoteCall';


/**
 * This class provides access to every call related feature This class must
 * never be directly instantiated, instances of this class can be obtained
 * using Session#getCallManager.
 */
export class CallManager {
	emitter: EventEmitter2;

	/**
	 * Creates a new call instance for communication with the specified recipient.
	 */
	createCall(to: string): Promise<Call>;

	getCallLog(): Promise<CallLog>;

	getDefaultMediaConstraints(): MediaStreamConstraints;

	/**
	 * Get a list of remote calls where user is currently participating.
	 */
	getRemoteCalls(): Promise<RemoteCall[]>;

	/**
	 * Pulls remote call from remote session.
	 */
	pull(remoteCall: RemoteCall): Promise<Call>;

	setDefaultMediaConstraints(defaultMediaConstraints: MediaStreamConstraints): void;
}
