/**
 * Instances of this class represents a file in a chat message. This class must not be
 * directly instantiated. Instances of this class can be obtained using {@link ChatMessage#getData}.
 */
export declare class ChatMessageFile {
    private name;
    private url;
    private cachedType?;
    /** @ignore */
    constructor(name: string, url: string);
    /**
     * @desc Returns the name of the file.
     * @return {string} Name of the file
     */
    getName(): string;
    /**
     * @desc Returns the URL of the file.
     * @return {string} URL of the file
     */
    getUrl(): string;
    /**
     * @desc Returns the mime-type of the file.
     * @return {Promise<string>} A promise fulfilled with the mime-type of the file
     * @deprecated You must directly send a HEAD request to the URL instead of relying on this method
     * e.g.: fetch(chatFile.getUrl(), {method: 'HEAD'})
     */
    getType(): Promise<string | undefined>;
}
