import {EventEmitter2} from 'eventemitter2';
import {Contact} from './Contact';
import {OwnPresence} from './OwnPresence';
import {Presence} from './Presence';

/**
 * ContactManager instance is obtained by calling the Session#getContactManager
 * method of Session and must not be directly instantiated. Once the
 * ContactManager instance is obtained ContactManager#init method must be
 * called to initialize it.
 */
export declare class ContactManager extends EventEmitter2 {

	/**
	 * Allows to change the presence of this session.
	 */
	ownPresence: OwnPresence;

	prototypes: {Contact: any; GroupContact: any; Presence: any; OwnPresence: any};

	/**
	 * Call stack.addContact once the manager is initialized and return a promise.
	 */
	createContact(displayName: string, phones: string | Array<{name: string; address: string}>, emails: Array<{email: string}>): any;

	getContactByAddress(address: string, sync: undefined): [Contact, Promise<Contact>];
	/** @deprecated */
	getContactByAddress(address: string): Contact;
	/** @deprecated */
	getContactByAddress<T extends boolean>(address: string, sync: T): T extends true ? Contact : Promise<Contact>;
	getNewContactByAddress(address: string): [Contact, Promise<Contact>];

	/**
	 * Retrieves a contact given an email
	 */
	getContactByEmail(email: string): Contact;

	/**
	 * Retrieves a contact given a WAC id
	 */
	getContactByWacId(wacId: any): Contact;

	/**
	 * Retrieves a list with the available contacts
	 */
	getContacts(): Contact[];

	getFakeContact(opts: {
		id: string;
		name: string;
		presence?: Presence;
		avatar?: string;
		phone?: string;
		email?: string;
	}): Contact;

	/**
	 * Retrieves the presence of a user given an address
	 */
	getPresenceByAddress(address: any): Promise<Presence>;

	/**
	 * Retrieves the presence of a user given its WAC id
	 */
	getPresenceByWacId(wacId: any): Contact;

	/**
	 * Initializes the contact manager
	 */
	init(): Promise<ContactManager>;

	/**
	 * Clears all user contacts data and invalidates the cache from the persistent storage
	 */
	clearContactsDataFromPersistentStorage(): void;

	/**
	 * Uninitializes the contact manager
	 */
	uninit(): Promise<void>;
}
