import { Set } from 'immutable';
import { MeetingParticipant } from './MeetingParticipant';
export interface MeetingParameters {
    id: string;
    name: string;
    creator: string;
    participants: Iterable<MeetingParticipant>;
    language: string;
    validSince: number;
    validUntil: number;
    url: string;
    phone: string;
    isPasswordProtected: boolean;
}
/**
 * Represents a meeting. This class is immutable.
 * All the properties are readonly and must never be changed.
 * Instances of this class are usually obtained using {@link MeetingManager}
 */
export declare class Meeting {
    readonly id: string;
    readonly name: string;
    readonly creator: string;
    readonly participants: Set<MeetingParticipant>;
    readonly language: string;
    readonly validSince: number;
    readonly validUntil: number;
    readonly url: string;
    readonly phone: string;
    readonly isPasswordProtected: boolean;
    /** @ignore */
    constructor(data: MeetingParameters);
    /**
     * Check if the participant in a meeting is online
     * @return {boolean}
     */
    isOnline(): boolean;
    /**
     * Returns a new meeting with the provided values changed
     * @param {object} [options={}]
     * @param {string} [options.name]
     * @param {Iterable<MeetingParticipant>} [options.participants]
     * @param {string} [options.language]
     * @param {number} [options.validSince]
     * @param {number} [options.validUntil]
     * @param {string} [options.url]
     * @param {string} [options.phone]
     * @return {Meeting}
     */
    with({ name, participants, language, validSince, validUntil, url, phone, isPasswordProtected, }?: Partial<Omit<MeetingParameters, 'id' | 'creator'>>): Meeting;
}
