import {User} from '../session/User';

/**
 * Element that enables user resolution. Previously resolved users are stored
 * in a local collection that is updated when some of the requested addresses
 * change.
 */
export class UserManager {
	/**
	 * Get the address associated with given user Id.
	 */
	getAddress(userId: string): string;

	/**
	 * Returns the gateway username associated with an user username.
	 */
	getGatewayUsername(username: string, ignoreErrors: boolean): Promise<string>;

	/**
	 * Returns the gateway usernames associated with an user username.
	 */
	getGatewayUsernames(usernames: any, ignoreErrors: boolean): any;

	/**
	 * Obtains own user WAC address
	 */
	getOwnAddress(): string;

	/**
	 * Get the userId associated with given user address.
	 */
	getUserId(address: string): string;

	/**
	 * Returns an user username given a gateway username.
	 */
	getUsername(gatewayUsername: string, ignoreErrors: boolean): Promise<string>;

	/**
	 * Initialize UsersManager.
	 */
	init(stack: any): Promise<any>;

	/**
	 * Checks if given address is a WAC user address
	 */
	isAddress(address: string): boolean;

	/**
	 * Checks if given address is own WAC user address
	 */
	isOwnAddress(address: string): boolean;

	/**
	 * Request an address resolution.
	 */
	resolveUser(address: string): Promise<User | undefined>;

	/**
	 * Deinitialize UsersManager.
	 */
	uninit(): void;
}
